@@ -317,7 +317,7 @@ void findcrashfiles()
 }  
 
 /*----------------------------------------------------------------------*/
-/* Match a filename extension against the file filter string.		*/
+/* Match a filename extension against the file filter list.		*/
 /*----------------------------------------------------------------------*/
 
 #if !defined(XC_WIN32) || defined(TCL_WRAPPER)
@@ -325,11 +325,27 @@ void findcrashfiles()
 Boolean match_filter(char *fname, char *filter)
 {
    char *dotptr = strrchr(fname, '.');
+   char *filtptr, *endptr;
+   int filtlen, extlen;
 
-   if ((dotptr != NULL) && (filter != NULL) &&
-       (filter[0] != '\0') && (strstr(dotptr, filter) != NULL))
-      return True;
+   if (filter == NULL) return False;
+   if (dotptr == NULL) return False;
 
+   dotptr++;
+   extlen = strlen(dotptr);
+   filtptr = filter;
+
+   while (*filtptr != '\0') {
+      endptr = filtptr;
+      while (*endptr != '\0' && !isspace(*endptr)) endptr++;
+      filtlen = (int)(endptr - filtptr);
+      if (filtlen == extlen)
+         if (!strncmp(dotptr, filtptr, extlen))
+	    return True;
+
+      filtptr = endptr;
+      while (*filtptr != '\0' && isspace(*filtptr)) filtptr++;
+   }
    return False;
 }
 
