@@ -43,7 +43,6 @@ extern Pixmap STIPPLE[8];
 extern XCWindowData *areawin;
 extern Globaldata xobjs;
 extern int *appcolors;
-extern short textpos, textend;
 
 /*------------------------------------------------------------------------*/
 /* find the squared length of a wire (or distance between two points in   */
@@ -528,13 +527,11 @@ void user_to_window(XPoint upt, XPoint *wpt)
 /*----------------------------------------------------------------------*/
 
 /*----------------------------------------------------------------------*/
-/* Return rotation relative to the top level				*/
+/* Return rotation relative to a specific CTM				*/
 /*----------------------------------------------------------------------*/
 
-int UTopRotate()
+int UGetCTMRotation(Matrix *ctm)
 {
-   int rotate;
-   Matrix *ctm = DCTM;
    float topscale = UTopScale();
    float rads = (float)atan2((double)(ctm->d / topscale),
 			(double)(ctm->a / topscale));
@@ -543,13 +540,67 @@ int UTopRotate()
 }
 
 /*----------------------------------------------------------------------*/
-/* Return scale relative to top-level					*/
+/* Return rotation relative to the top level				*/
+/* Note that UTopRotation() is also the rotation relative to the window	*/
+/* since the top-level drawing page is always upright relative to the	*/
+/* window.  Thus, there is no routine UTopDrawingRotation().		*/
+/*----------------------------------------------------------------------*/
+
+int UTopRotation()
+{
+   return UGetCTMRotation(DCTM);
+}
+
+/*----------------------------------------------------------------------*/
+/* Return scale relative to a specific CTM				*/
+/*----------------------------------------------------------------------*/
+
+float UGetCTMScale(Matrix *ctm)
+{
+   return (float)(sqrt((double)(ctm->a * ctm->a + ctm->d * ctm->d)));
+}
+
+/*----------------------------------------------------------------------*/
+/* Return scale relative to window					*/
 /*----------------------------------------------------------------------*/
 
 float UTopScale()
 {
-   Matrix *ctm = DCTM;
-   return (float)(sqrt((double)(ctm->a * ctm->a + ctm->d * ctm->d)));
+   return UGetCTMScale(DCTM);
+}
+
+/*----------------------------------------------------------------------*/
+/* Return scale multiplied by length					*/
+/*----------------------------------------------------------------------*/
+
+float UTopTransScale(float length)
+{
+   return (float)(length * UTopScale());
+}
+
+/*----------------------------------------------------------------------*/
+/* Return scale relative to the top-level schematic (not the window)	*/
+/*----------------------------------------------------------------------*/
+
+float UTopDrawingScale()
+{
+   Matrix lctm, wctm;
+   UCopyCTM(DCTM, &lctm);
+   UResetCTM(&wctm);
+   UMakeWCTM(&wctm);
+   InvertCTM(&wctm);
+   UPreMultCTMbyMat(&wctm, &lctm);
+   return UGetCTMScale(&wctm);
+}
+
+/*----------------------------------------------------------------------*/
+/* Return position offset relative to a specific CTM			*/
+/*----------------------------------------------------------------------*/
+
+void UGetCTMOffset(Matrix *ctm, int *offx, int *offy)
+{
+   if (offx) *offx = (int)ctm->c;
+   if (offy) *offy = (int)ctm->f;
 }
 
 /*----------------------------------------------------------------------*/
@@ -558,16 +609,22 @@ float UTopScale()
 
 void UTopOffset(int *offx, int *offy)
 {
-   Matrix *ctm = DCTM;
-   *offx = (int)ctm->c;
-   *offy = (int)ctm->f;
+   UGetCTMOffset(DCTM, offx, offy);
 }
 
+/*----------------------------------------------------------------------*/
+/* Return postion relative to the top-level schematic (not the window)	*/
 /*----------------------------------------------------------------------*/
 
-float UTopTransScale(float length)
+void UTopDrawingOffset(int *offx, int *offy)
 {
-   return (float)(length * UTopScale());
+   Matrix lctm, wctm;
+   UCopyCTM(DCTM, &lctm);
+   UResetCTM(&wctm);
+   UMakeWCTM(&wctm);
+   InvertCTM(&wctm);
+   UPreMultCTMbyMat(&wctm, &lctm);
+   UGetCTMOffset(&wctm, offx, offy);
 }
 
 /*----------------------------------------------------------------------*/
@@ -1341,6 +1398,7 @@ void calcbboxinst(objinstptr thisinst)
 
    short pllx, plly, purx, pury;
    Boolean hasschembbox = FALSE;
+   Boolean didparamsubs = FALSE;
 
    if (thisinst == NULL) return;
 
@@ -1368,8 +1426,13 @@ void calcbboxinst(objinstptr thisinst)
 	 }
       }
 
-      if (has_param(*gelem))
+      if (has_param(*gelem)) {
+	 if (didparamsubs == FALSE) {
+	    psubstitute(thisinst);
+	    didparamsubs = TRUE;
+	 }
 	 calcbboxsingle(gelem, thisinst, &llx, &lly, &urx, &ury);
+      }
    }
 
    thisinst->bbox.lowerleft.x = llx;
@@ -1871,9 +1934,9 @@ void UDrawTextLine(labelptr curlabel, short tpos)
 
 void UDrawTLine(labelptr curlabel)
 {
-   UDrawTextLine(curlabel, textpos);
-   if ((textend > 0) && (textend < textpos)) {
-      UDrawTextLine(curlabel, textend);
+   UDrawTextLine(curlabel, areawin->textpos);
+   if ((areawin->textend > 0) && (areawin->textend < areawin->textpos)) {
+      UDrawTextLine(curlabel, areawin->textend);
    }
 }
 
