@@ -301,6 +301,10 @@ extern TechPtr LookupTechnology(char *);
 extern TechPtr GetObjectTechnology(objectptr);
 extern TechPtr AddNewTechnology(char *, char *);
 extern void AddObjectTechnology(objectptr);
+extern void TechReplaceSave();
+extern void TechReplaceRestore();
+extern void TechReplaceAll();
+extern void TechReplaceNone();
 
 #ifdef TCL_WRAPPER
 extern void setfile(char *, int);
@@ -361,10 +365,14 @@ extern void updateinstparam(objectptr);
 extern short checkbounds(void);
 extern void window_to_user(short, short, XPoint *);
 extern void user_to_window(XPoint, XPoint *);
+
 extern float UTopScale(void);
-extern int UTopRotation(void);
-extern void UTopOpffset(int *, int *);
 extern float UTopTransScale(float);
+extern float UTopDrawingScale(void);
+extern int UTopRotation(void);
+extern void UTopOffset(int *, int *);
+extern void UTopDrawingOffset(int *, int *);
+
 extern XPoint UGetCursor(void);
 extern XPoint UGetCursorPos(void);
 extern void u2u_snap(XPoint *);
@@ -724,7 +732,8 @@ extern void free_element_param(genericptr, eparamptr);
 extern oparamptr make_new_parameter(char *);
 extern eparamptr make_new_eparam(char *);
 
-extern Boolean makeexprparam(objectptr, char *, char *, int);
+extern char *getnumericalpkey(u_int);
+extern char *makeexprparam(objectptr, char *, char *, int);
 extern Boolean makefloatparam(objectptr, char *, float);
 extern Boolean makestringparam(objectptr, char *, stringpart *);
 extern void std_eparam(genericptr, char *);
