@@ -1133,7 +1133,6 @@ void pre_initialize()
    xobjs.showtech = FALSE;
    xobjs.suspend = (char)0;	/* Suspend graphics until finished with startup */
    xobjs.new_changes = 0;
-   xobjs.do_replace = -1;	/* default: replace NONE */
    xobjs.filefilter = TRUE;
    xobjs.tempfile = NULL;
    xobjs.retain_backup = False;	/* default: remove backup after file write */
@@ -1170,6 +1169,9 @@ void pre_initialize()
 
    fontcount = 0;
    fonts = (fontinfo *) malloc(sizeof(fontinfo));
+   fonts[0].encoding = NULL;	/* To prevent segfaults */
+   fonts[0].psname = NULL;
+   fonts[0].family = NULL;
 
    /* Initialization of objects requires values for the window width and height, */
    /* so set up the widgets and realize them first.				 */
