@@ -1417,6 +1417,8 @@ typedef struct _Technology {
 
 #define LIBRARY_CHANGED		0x01
 #define LIBRARY_READONLY	0x02
+#define LIBRARY_REPLACE		0x04	/* Replace instances when reading */
+#define LIBRARY_REPLACE_TEMP	0x08	/* Temporary store */
 
 /*----------------------------------------------------------------------*/
 /* A convenient structure for holding all the object lists		*/
@@ -1430,7 +1432,6 @@ typedef struct {
    Boolean	retain_backup;
    xcIntervalId	timeout_id;
    int		save_interval;
-   short	do_replace;
    Boolean	filefilter;	/* Is the file list filtered? */
    Boolean	hold;		/* allow HOLD modifiers on buttons */
    Boolean	showtech;	/* Write technology names in library */
